==> ui-framework-4.5.4-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractDocsTemplate.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractDocsTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Doc_7_1_11421343349 doc_7_1_11421343349;
	public DocsTemplate.Doc_7_1_11421343349. Doc_8_2_1109554097 doc_8_2_1109554097;
	public DocsTemplate.Doc_7_1_11421343349.Doc_8_2_1109554097. Doc_9_3_1557722831 doc_9_3_1557722831;
	public DocsTemplate.Doc_7_1_11421343349.Doc_8_2_1109554097. Doc_10_3_1646393896 doc_10_3_1646393896;
	public DocsTemplate.Doc_7_1_11421343349.Doc_8_2_1109554097. Links links;
	public DocsTemplate.Doc_7_1_11421343349.Doc_8_2_1109554097.Links. Doc_12_4_1763787603 doc_12_4_1763787603;
	public DocsTemplate.Doc_7_1_11421343349.Doc_8_2_1109554097.Links. Doc_13_4_01497502557 doc_13_4_01497502557;
	public Body body;
	public DocsTemplate.Body. DataBlock dataBlock;
	public DocsTemplate.Body.DataBlock. DataWidgets dataWidgets;
	public DocsTemplate.Body. CatalogBlock catalogBlock;
	public DocsTemplate.Body.CatalogBlock. CatalogWidgets catalogWidgets;
	public DocsTemplate.Body. OperationBlock operationBlock;
	public DocsTemplate.Body.OperationBlock. OperationWidgets operationWidgets;
	public DocsTemplate.Body. OtherBlock otherBlock;
	public DocsTemplate.Body.OtherBlock. OtherWidgets otherWidgets;

    public AbstractDocsTemplate(B box) {
        super(box);
        id("docsTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (doc_7_1_11421343349 == null) doc_7_1_11421343349 = register(new Doc_7_1_11421343349(box()).<Doc_7_1_11421343349>id("a_1777921359").owner(AbstractDocsTemplate.this));
		if (doc_7_1_11421343349 != null) doc_8_2_1109554097 = doc_7_1_11421343349.doc_8_2_1109554097;
		if (doc_8_2_1109554097 != null) doc_9_3_1557722831 = doc_7_1_11421343349.doc_8_2_1109554097.doc_9_3_1557722831;
		if (doc_8_2_1109554097 != null) doc_10_3_1646393896 = doc_7_1_11421343349.doc_8_2_1109554097.doc_10_3_1646393896;
		if (doc_8_2_1109554097 != null) links = doc_7_1_11421343349.doc_8_2_1109554097.links;
		if (links != null) doc_12_4_1763787603 = doc_7_1_11421343349.doc_8_2_1109554097.links.doc_12_4_1763787603;
		if (links != null) doc_13_4_01497502557 = doc_7_1_11421343349.doc_8_2_1109554097.links.doc_13_4_01497502557;
		if (body == null) body = register(new Body(box()).<Body>id("a_1642819251").owner(AbstractDocsTemplate.this));
		if (body != null) dataBlock = body.dataBlock;
		if (dataBlock != null) dataWidgets = body.dataBlock.dataWidgets;
		if (body != null) catalogBlock = body.catalogBlock;
		if (catalogBlock != null) catalogWidgets = body.catalogBlock.catalogWidgets;
		if (body != null) operationBlock = body.operationBlock;
		if (operationBlock != null) operationWidgets = body.operationBlock.operationWidgets;
		if (body != null) otherBlock = body.otherBlock;
		if (otherBlock != null) otherWidgets = body.otherBlock.otherWidgets;
	}

	public class Doc_7_1_11421343349 extends io.intino.alexandria.ui.displays.components.Header<io.intino.alexandria.ui.displays.notifiers.HeaderNotifier, B>  {
		public DocsTemplate.Doc_7_1_11421343349. Doc_8_2_1109554097 doc_8_2_1109554097;

		public Doc_7_1_11421343349(B box) {
			super(box);

			_color("white");
		}

		@Override
		public void init() {
			super.init();
			if (doc_8_2_1109554097 == null) doc_8_2_1109554097 = register(new Doc_8_2_1109554097(box()).<Doc_8_2_1109554097>id("a_477928552").owner(AbstractDocsTemplate.this));
		}

		public class Doc_8_2_1109554097 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public DocsTemplate.Doc_7_1_11421343349.Doc_8_2_1109554097. Doc_9_3_1557722831 doc_9_3_1557722831;
			public DocsTemplate.Doc_7_1_11421343349.Doc_8_2_1109554097. Doc_10_3_1646393896 doc_10_3_1646393896;
			public DocsTemplate.Doc_7_1_11421343349.Doc_8_2_1109554097. Links links;

			public Doc_8_2_1109554097(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (doc_9_3_1557722831 == null) doc_9_3_1557722831 = register(new Doc_9_3_1557722831(box()).<Doc_9_3_1557722831>id("a757344438").owner(AbstractDocsTemplate.this));
				if (doc_10_3_1646393896 == null) doc_10_3_1646393896 = register(new Doc_10_3_1646393896(box()).<Doc_10_3_1646393896>id("a_158557124").owner(AbstractDocsTemplate.this));
				if (links == null) links = register(new Links(box()).<Links>id("a_433533055").owner(AbstractDocsTemplate.this));
			}

			public class Doc_9_3_1557722831 extends io.intino.alexandria.ui.displays.components.Image<io.intino.alexandria.ui.displays.notifiers.ImageNotifier, B>  {

				public Doc_9_3_1557722831(B box) {
					super(box);
					_value(AbstractDocsTemplate.class.getResource("/images/intino.png"));
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class Doc_10_3_1646393896 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public Doc_10_3_1646393896(B box) {
					super(box);
					_value("intino");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class Links extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public DocsTemplate.Doc_7_1_11421343349.Doc_8_2_1109554097.Links. Doc_12_4_1763787603 doc_12_4_1763787603;
				public DocsTemplate.Doc_7_1_11421343349.Doc_8_2_1109554097.Links. Doc_13_4_01497502557 doc_13_4_01497502557;

				public Links(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (doc_12_4_1763787603 == null) doc_12_4_1763787603 = register(new Doc_12_4_1763787603(box()).<Doc_12_4_1763787603>id("a_864268246").owner(AbstractDocsTemplate.this));
					if (doc_13_4_01497502557 == null) doc_13_4_01497502557 = register(new Doc_13_4_01497502557(box()).<Doc_13_4_01497502557>id("a260507758").owner(AbstractDocsTemplate.this));
				}

				public class Doc_12_4_1763787603 extends io.intino.alexandria.ui.displays.components.OpenPage<io.intino.alexandria.ui.displays.notifiers.OpenPageNotifier, B>  {

					public Doc_12_4_1763787603(B box) {
						super(box);
						_title("home");
						_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
						_path("/");
					}

					@Override
					public void init() {
						super.init();
					}
				}

				public class Doc_13_4_01497502557 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public Doc_13_4_01497502557(B box) {
						super(box);
						_value("docs");
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}
		}
	}

	public class Body extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public DocsTemplate.Body. DataBlock dataBlock;
		public DocsTemplate.Body. CatalogBlock catalogBlock;
		public DocsTemplate.Body. OperationBlock operationBlock;
		public DocsTemplate.Body. OtherBlock otherBlock;

		public Body(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (dataBlock == null) dataBlock = register(new DataBlock(box()).<DataBlock>id("a_149344623").owner(AbstractDocsTemplate.this));
			if (catalogBlock == null) catalogBlock = register(new CatalogBlock(box()).<CatalogBlock>id("a_1376863834").owner(AbstractDocsTemplate.this));
			if (operationBlock == null) operationBlock = register(new OperationBlock(box()).<OperationBlock>id("a1885192344").owner(AbstractDocsTemplate.this));
			if (otherBlock == null) otherBlock = register(new OtherBlock(box()).<OtherBlock>id("a_1326767729").owner(AbstractDocsTemplate.this));
		}

		public class DataBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public DocsTemplate.Body.DataBlock. DataWidgets dataWidgets;

			public DataBlock(B box) {
				super(box);
				label("data widgets");
			}

			@Override
			public void init() {
				super.init();
				if (dataWidgets == null) dataWidgets = register(new DataWidgets((UiFrameworkBox)box()).<DataWidgets>id("a_1887322377").owner(AbstractDocsTemplate.this));
			}

			public class DataWidgets extends io.intino.alexandria.ui.displays.components.Multiple<UiFrameworkBox,WidgetSummaryMold, io.intino.alexandria.schemas.Widget>  {

				public DataWidgets(UiFrameworkBox box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public WidgetSummaryMold add(io.intino.alexandria.schemas.Widget value) {
					WidgetSummaryMold child = new WidgetSummaryMold(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "dataWidgets");
					child.value(value);
				    notifyAdd(child, value);
					return child;
				}
				@Override
				public void remove(WidgetSummaryMold child) {
					removeChild(child, "dataWidgets");
				}
				public void clear() {
				    super.clear("dataWidgets");
				}
			}
		}

		public class CatalogBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public DocsTemplate.Body.CatalogBlock. CatalogWidgets catalogWidgets;

			public CatalogBlock(B box) {
				super(box);
				label("catalog widgets");
			}

			@Override
			public void init() {
				super.init();
				if (catalogWidgets == null) catalogWidgets = register(new CatalogWidgets((UiFrameworkBox)box()).<CatalogWidgets>id("a1972960271").owner(AbstractDocsTemplate.this));
			}

			public class CatalogWidgets extends io.intino.alexandria.ui.displays.components.Multiple<UiFrameworkBox,WidgetSummaryMold, io.intino.alexandria.schemas.Widget>  {

				public CatalogWidgets(UiFrameworkBox box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public WidgetSummaryMold add(io.intino.alexandria.schemas.Widget value) {
					WidgetSummaryMold child = new WidgetSummaryMold(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "catalogWidgets");
					child.value(value);
				    notifyAdd(child, value);
					return child;
				}
				@Override
				public void remove(WidgetSummaryMold child) {
					removeChild(child, "catalogWidgets");
				}
				public void clear() {
				    super.clear("catalogWidgets");
				}
			}
		}

		public class OperationBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public DocsTemplate.Body.OperationBlock. OperationWidgets operationWidgets;

			public OperationBlock(B box) {
				super(box);
				label("operation widgets");
			}

			@Override
			public void init() {
				super.init();
				if (operationWidgets == null) operationWidgets = register(new OperationWidgets((UiFrameworkBox)box()).<OperationWidgets>id("a1764951055").owner(AbstractDocsTemplate.this));
			}

			public class OperationWidgets extends io.intino.alexandria.ui.displays.components.Multiple<UiFrameworkBox,WidgetSummaryMold, io.intino.alexandria.schemas.Widget>  {

				public OperationWidgets(UiFrameworkBox box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public WidgetSummaryMold add(io.intino.alexandria.schemas.Widget value) {
					WidgetSummaryMold child = new WidgetSummaryMold(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "operationWidgets");
					child.value(value);
				    notifyAdd(child, value);
					return child;
				}
				@Override
				public void remove(WidgetSummaryMold child) {
					removeChild(child, "operationWidgets");
				}
				public void clear() {
				    super.clear("operationWidgets");
				}
			}
		}

		public class OtherBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public DocsTemplate.Body.OtherBlock. OtherWidgets otherWidgets;

			public OtherBlock(B box) {
				super(box);
				label("other widgets");
			}

			@Override
			public void init() {
				super.init();
				if (otherWidgets == null) otherWidgets = register(new OtherWidgets((UiFrameworkBox)box()).<OtherWidgets>id("a693468719").owner(AbstractDocsTemplate.this));
			}

			public class OtherWidgets extends io.intino.alexandria.ui.displays.components.Multiple<UiFrameworkBox,WidgetSummaryMold, io.intino.alexandria.schemas.Widget>  {

				public OtherWidgets(UiFrameworkBox box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public WidgetSummaryMold add(io.intino.alexandria.schemas.Widget value) {
					WidgetSummaryMold child = new WidgetSummaryMold(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "otherWidgets");
					child.value(value);
				    notifyAdd(child, value);
					return child;
				}
				@Override
				public void remove(WidgetSummaryMold child) {
					removeChild(child, "otherWidgets");
				}
				public void clear() {
				    super.clear("otherWidgets");
				}
			}
		}
	}
}

==> ui-framework-4.13.4-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractDocsTemplate.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractDocsTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _7_1_11421343349 _7_1_11421343349;
	public DocsTemplate._7_1_11421343349. _8_2_1109554097 _8_2_1109554097;
	public DocsTemplate._7_1_11421343349._8_2_1109554097. _9_3_1557722831 _9_3_1557722831;
	public DocsTemplate._7_1_11421343349._8_2_1109554097. _10_3_1646393896 _10_3_1646393896;
	public DocsTemplate._7_1_11421343349._8_2_1109554097. Links links;
	public DocsTemplate._7_1_11421343349._8_2_1109554097.Links. _12_4_1763787603 _12_4_1763787603;
	public DocsTemplate._7_1_11421343349._8_2_1109554097.Links. _13_4_01497502557 _13_4_01497502557;
	public Body body;
	public DocsTemplate.Body. DataBlock dataBlock;
	public DocsTemplate.Body.DataBlock. DataWidgets dataWidgets;
	public DocsTemplate.Body. CatalogBlock catalogBlock;
	public DocsTemplate.Body.CatalogBlock. CatalogWidgets catalogWidgets;
	public DocsTemplate.Body. OperationBlock operationBlock;
	public DocsTemplate.Body.OperationBlock. OperationWidgets operationWidgets;
	public DocsTemplate.Body. OtherBlock otherBlock;
	public DocsTemplate.Body.OtherBlock. OtherWidgets otherWidgets;

    public AbstractDocsTemplate(B box) {
        super(box);
        id("docsTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (_7_1_11421343349 == null) _7_1_11421343349 = register(new _7_1_11421343349(box()).<_7_1_11421343349>id("a1207447471").owner(AbstractDocsTemplate.this));
		if (_7_1_11421343349 != null) _8_2_1109554097 = _7_1_11421343349._8_2_1109554097;
		if (_8_2_1109554097 != null) _9_3_1557722831 = _7_1_11421343349._8_2_1109554097._9_3_1557722831;
		if (_8_2_1109554097 != null) _10_3_1646393896 = _7_1_11421343349._8_2_1109554097._10_3_1646393896;
		if (_8_2_1109554097 != null) links = _7_1_11421343349._8_2_1109554097.links;
		if (links != null) _12_4_1763787603 = _7_1_11421343349._8_2_1109554097.links._12_4_1763787603;
		if (links != null) _13_4_01497502557 = _7_1_11421343349._8_2_1109554097.links._13_4_01497502557;
		if (body == null) body = register(new Body(box()).<Body>id("a_1642819251").owner(AbstractDocsTemplate.this));
		if (body != null) dataBlock = body.dataBlock;
		if (dataBlock != null) dataWidgets = body.dataBlock.dataWidgets;
		if (body != null) catalogBlock = body.catalogBlock;
		if (catalogBlock != null) catalogWidgets = body.catalogBlock.catalogWidgets;
		if (body != null) operationBlock = body.operationBlock;
		if (operationBlock != null) operationWidgets = body.operationBlock.operationWidgets;
		if (body != null) otherBlock = body.otherBlock;
		if (otherBlock != null) otherWidgets = body.otherBlock.otherWidgets;
	}

	public class _7_1_11421343349 extends io.intino.alexandria.ui.displays.components.Header<io.intino.alexandria.ui.displays.notifiers.HeaderNotifier, B>  {
		public DocsTemplate._7_1_11421343349. _8_2_1109554097 _8_2_1109554097;

		public _7_1_11421343349(B box) {
			super(box);

			_color("white");
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_1109554097 == null) _8_2_1109554097 = register(new _8_2_1109554097(box()).<_8_2_1109554097>id("a_838708836").owner(AbstractDocsTemplate.this));
		}

		public class _8_2_1109554097 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public DocsTemplate._7_1_11421343349._8_2_1109554097. _9_3_1557722831 _9_3_1557722831;
			public DocsTemplate._7_1_11421343349._8_2_1109554097. _10_3_1646393896 _10_3_1646393896;
			public DocsTemplate._7_1_11421343349._8_2_1109554097. Links links;

			public _8_2_1109554097(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_1557722831 == null) _9_3_1557722831 = register(new _9_3_1557722831(box()).<_9_3_1557722831>id("a_942684802").owner(AbstractDocsTemplate.this));
				if (_10_3_1646393896 == null) _10_3_1646393896 = register(new _10_3_1646393896(box()).<_10_3_1646393896>id("a_1319856012").owner(AbstractDocsTemplate.this));
				if (links == null) links = register(new Links(box()).<Links>id("a_433533055").owner(AbstractDocsTemplate.this));
			}

			public class _9_3_1557722831 extends io.intino.alexandria.ui.displays.components.Image<io.intino.alexandria.ui.displays.notifiers.ImageNotifier, B>  {

				public _9_3_1557722831(B box) {
					super(box);
					_value(AbstractDocsTemplate.class.getResource("/images/intino.png"));
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class _10_3_1646393896 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _10_3_1646393896(B box) {
					super(box);
					_value("intino");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class Links extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public DocsTemplate._7_1_11421343349._8_2_1109554097.Links. _12_4_1763787603 _12_4_1763787603;
				public DocsTemplate._7_1_11421343349._8_2_1109554097.Links. _13_4_01497502557 _13_4_01497502557;

				public Links(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_12_4_1763787603 == null) _12_4_1763787603 = register(new _12_4_1763787603(box()).<_12_4_1763787603>id("a_345371218").owner(AbstractDocsTemplate.this));
					if (_13_4_01497502557 == null) _13_4_01497502557 = register(new _13_4_01497502557(box()).<_13_4_01497502557>id("a_833553558").owner(AbstractDocsTemplate.this));
				}

				public class _12_4_1763787603 extends io.intino.alexandria.ui.displays.components.OpenPage<io.intino.alexandria.ui.displays.notifiers.OpenPageNotifier, B>  {

					public _12_4_1763787603(B box) {
						super(box);
						_title("home");
						_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
						_path("/");
					}

					@Override
					public void init() {
						super.init();
					}
				}

				public class _13_4_01497502557 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public _13_4_01497502557(B box) {
						super(box);
						_value("docs");
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}
		}
	}

	public class Body extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public DocsTemplate.Body. DataBlock dataBlock;
		public DocsTemplate.Body. CatalogBlock catalogBlock;
		public DocsTemplate.Body. OperationBlock operationBlock;
		public DocsTemplate.Body. OtherBlock otherBlock;

		public Body(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (dataBlock == null) dataBlock = register(new DataBlock(box()).<DataBlock>id("a_149344623").owner(AbstractDocsTemplate.this));
			if (catalogBlock == null) catalogBlock = register(new CatalogBlock(box()).<CatalogBlock>id("a_1376863834").owner(AbstractDocsTemplate.this));
			if (operationBlock == null) operationBlock = register(new OperationBlock(box()).<OperationBlock>id("a1885192344").owner(AbstractDocsTemplate.this));
			if (otherBlock == null) otherBlock = register(new OtherBlock(box()).<OtherBlock>id("a_1326767729").owner(AbstractDocsTemplate.this));
		}

		public class DataBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public DocsTemplate.Body.DataBlock. DataWidgets dataWidgets;

			public DataBlock(B box) {
				super(box);
				label("data widgets");
			}

			@Override
			public void init() {
				super.init();
				if (dataWidgets == null) dataWidgets = register(new DataWidgets((UiFrameworkBox)box()).<DataWidgets>id("a_1887322377").owner(AbstractDocsTemplate.this));
			}

			public class DataWidgets extends io.intino.alexandria.ui.displays.components.Multiple<UiFrameworkBox,WidgetSummaryMold, io.intino.alexandria.schemas.Widget> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<UiFrameworkBox,WidgetSummaryMold, io.intino.alexandria.schemas.Widget> {

				public DataWidgets(UiFrameworkBox box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public WidgetSummaryMold add(io.intino.alexandria.schemas.Widget value) {
					WidgetSummaryMold child = new WidgetSummaryMold(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "dataWidgets");
					child.value(value);
				    notifyAdd(child, value);
					return child;
				}
				@Override
				public void remove(WidgetSummaryMold child) {
					removeChild(child, "dataWidgets");
				}
				public void clear() {
				    super.clear("dataWidgets");
				}
			}
		}

		public class CatalogBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public DocsTemplate.Body.CatalogBlock. CatalogWidgets catalogWidgets;

			public CatalogBlock(B box) {
				super(box);
				label("catalog widgets");
			}

			@Override
			public void init() {
				super.init();
				if (catalogWidgets == null) catalogWidgets = register(new CatalogWidgets((UiFrameworkBox)box()).<CatalogWidgets>id("a1972960271").owner(AbstractDocsTemplate.this));
			}

			public class CatalogWidgets extends io.intino.alexandria.ui.displays.components.Multiple<UiFrameworkBox,WidgetSummaryMold, io.intino.alexandria.schemas.Widget> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<UiFrameworkBox,WidgetSummaryMold, io.intino.alexandria.schemas.Widget> {

				public CatalogWidgets(UiFrameworkBox box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public WidgetSummaryMold add(io.intino.alexandria.schemas.Widget value) {
					WidgetSummaryMold child = new WidgetSummaryMold(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "catalogWidgets");
					child.value(value);
				    notifyAdd(child, value);
					return child;
				}
				@Override
				public void remove(WidgetSummaryMold child) {
					removeChild(child, "catalogWidgets");
				}
				public void clear() {
				    super.clear("catalogWidgets");
				}
			}
		}

		public class OperationBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public DocsTemplate.Body.OperationBlock. OperationWidgets operationWidgets;

			public OperationBlock(B box) {
				super(box);
				label("operation widgets");
			}

			@Override
			public void init() {
				super.init();
				if (operationWidgets == null) operationWidgets = register(new OperationWidgets((UiFrameworkBox)box()).<OperationWidgets>id("a1764951055").owner(AbstractDocsTemplate.this));
			}

			public class OperationWidgets extends io.intino.alexandria.ui.displays.components.Multiple<UiFrameworkBox,WidgetSummaryMold, io.intino.alexandria.schemas.Widget> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<UiFrameworkBox,WidgetSummaryMold, io.intino.alexandria.schemas.Widget> {

				public OperationWidgets(UiFrameworkBox box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public WidgetSummaryMold add(io.intino.alexandria.schemas.Widget value) {
					WidgetSummaryMold child = new WidgetSummaryMold(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "operationWidgets");
					child.value(value);
				    notifyAdd(child, value);
					return child;
				}
				@Override
				public void remove(WidgetSummaryMold child) {
					removeChild(child, "operationWidgets");
				}
				public void clear() {
				    super.clear("operationWidgets");
				}
			}
		}

		public class OtherBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public DocsTemplate.Body.OtherBlock. OtherWidgets otherWidgets;

			public OtherBlock(B box) {
				super(box);
				label("other widgets");
			}

			@Override
			public void init() {
				super.init();
				if (otherWidgets == null) otherWidgets = register(new OtherWidgets((UiFrameworkBox)box()).<OtherWidgets>id("a693468719").owner(AbstractDocsTemplate.this));
			}

			public class OtherWidgets extends io.intino.alexandria.ui.displays.components.Multiple<UiFrameworkBox,WidgetSummaryMold, io.intino.alexandria.schemas.Widget> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<UiFrameworkBox,WidgetSummaryMold, io.intino.alexandria.schemas.Widget> {

				public OtherWidgets(UiFrameworkBox box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public WidgetSummaryMold add(io.intino.alexandria.schemas.Widget value) {
					WidgetSummaryMold child = new WidgetSummaryMold(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "otherWidgets");
					child.value(value);
				    notifyAdd(child, value);
					return child;
				}
				@Override
				public void remove(WidgetSummaryMold child) {
					removeChild(child, "otherWidgets");
				}
				public void clear() {
				    super.clear("otherWidgets");
				}
			}
		}
	}
}
